@@ -22,16 +22,6 @@ test_that("llh is approximatied for basic statistics", {
 })
 
 
-test_that("calcStatLLH works for Stat_PoiSmooth", {
-  skip("Smoothing not implemented")
-  glm_fit <- fit_glm(smooth_stat, smooth_sim_data)
-  
-  #ll <- calcStatLLH(smooth_stat, glm_fit, c(x=.5, y=.5), scaling_factor=1)
-  #expect_true(is.numeric(ll))
-  #expect_true(0 <= exp(ll) | exp(ll) <= 1)
-})
-
-
 test_that("llh is approximatied for complete models", {
   model <- create_test_model()
   data <- create_test_data(model)
